# Third-Party Notices

This morphology generator is based on the work of Ondřej Tichý's thesis,
Morphological Analyser of Old English (2017)
https://www.researchgate.net/publication/318926182_Morphological_analyser_of_old_english.

The upstream morphological generator Perl code and data is (c) Ondřej Tichý,
is released under the CC BY 4.0 license.

Changes made to in this repository by Christopher Malek are released under the
MIT license.

All other code implemented directly by Christopher Malek, also released under
the MIT license.
